#========================================================================================
# package      DE_EPAGES::Content::Hooks::Object
# state        public
# description  delete shorturlredirections of startpage
#========================================================================================
package DE_EPAGES::Content::Hooks::Object;

use strict;
use DE_EPAGES::Content::API::Table::ShortUrlRedirection qw (DeleteShortUrlRedirection GetInfoShortUrlRedirectionsByContentObjectID GetPKeyShortUrlRedirectionsByContentObjectID UpdateShortUrlRedirection);
use DE_EPAGES::Trigger::API::Trigger qw (TriggerHook);
use feature 'switch';

#========================================================================================
# function     OnAfterDeleteChildObject
#----------------------------------------------------------------------------------------
# syntax       OnAfterDeleteChildObject($hParams);s
#----------------------------------------------------------------------------------------
# description  Deletes ShortURLredirection of this model when the startpage is deleted.
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of object Language, key is
#               <ul>
#                   <li>Object</li>
#                   <li>ObjectID</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnAfterDeleteChildObject {
    my ($hParams) = @_;
    my $Object = $hParams->{'Object'};
    my $ObjectID = $hParams->{'ObjectID'};
    return unless defined $ObjectID and defined $Object;

    # If current object is StartPage -> delete all shorturlredirections (inserted by deleteChildren).
    if($Object->instanceOf('StartPage')) {
        DeleteShortUrlRedirection($_) foreach @{GetPKeyShortUrlRedirectionsByContentObjectID($hParams->{'ObjectID'})};
    } elsif ($Object->instanceOf('ContentObject')) {
        my $hOldShortURL = {
            'Object' => $Object,
        };
        $hOldShortURL->{'ContentObjectID'} = $Object->get('Parent')->id;
        # Get correct parent of the object.
        TriggerHook('API_BeforeInsertShortURLRedirection', $hOldShortURL);

        # Move all redirections of this contentobject to his parent.
        foreach my $hShortUrlRedirection (@{GetInfoShortUrlRedirectionsByContentObjectID($Object->id)}) {
            my $ShortUrlRedirectionID = $hShortUrlRedirection->{'ShortUrlRedirectionID'};
            # Do not save redirects to the shop object.
            if(defined $hOldShortURL->{'ContentObjectID'} and $hOldShortURL->{'ContentObjectID'} != $hShortUrlRedirection->{'SiteID'}) {
                delete $hShortUrlRedirection->{'ShortUrlRedirectionID'};
                $hShortUrlRedirection->{'ContentObjectID'} = $hOldShortURL->{'ContentObjectID'};
                UpdateShortUrlRedirection($ShortUrlRedirectionID, $hShortUrlRedirection);
            } else {
                DeleteShortUrlRedirection($ShortUrlRedirectionID);
            }
        }
    }

    return;
}

#========================================================================================
# function     OnUnityURL
#----------------------------------------------------------------------------------------
# syntax       OnUnityURL($hParams);
#----------------------------------------------------------------------------------------
# description  sets public Unity SF url for legal pages
#----------------------------------------------------------------------------------------
# input        $hParams |
#               <ul>
#                   <li>Object
#                   <li>Params
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityURL {
    my ($hParams) = @_;

    my $LegalPage = $hParams->{'Object'};
    my $ClassAlias = $LegalPage->class->alias;
    my $hUnityParams = $hParams->{'Params'};

    given ($ClassAlias) {
        when ('Imprint') {
            $hUnityParams->{'UnityURL'} = $hUnityParams->{'UnityURL'} . '/l/contact';
        }
        when ('TermsAndConditions') {
            $hUnityParams->{'UnityURL'} = $hUnityParams->{'UnityURL'} . '/l/tac';
        }
        when ('CustomerInformation') {
            $hUnityParams->{'UnityURL'} = $hUnityParams->{'UnityURL'} . '/l/withdrawal';
        }
        when ('PrivacyPolicy') {
            $hUnityParams->{'UnityURL'} = $hUnityParams->{'UnityURL'} . '/l/privacy';
        }
        when ('ShippingAndPaymentInformation') {
            $hUnityParams->{'UnityURL'} = $hUnityParams->{'UnityURL'} . '/l/shipping';
        }
        when ('CookiePolicy') {
            $hUnityParams->{'UnityURL'} = $hUnityParams->{'UnityURL'} . '/l/cookiepolicy';
        }
    }

    return;
}

1;
