#========================================================================================
# package      DE_EPAGES::ContextualAppAds::Hooks::Shop
# state        public
# description  Hook functions of the cartridge ContextualAppAds.
#========================================================================================
package DE_EPAGES::ContextualAppAds::Hooks::Shop;

use strict;
use DE_EPAGES::ContextualAppAds::UI::JSON qw ( JSONWriteAppData );

#========================================================================================
# function     OnUnityViewStatusGeneral
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewStatusGeneral( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewStatusGeneral.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewStatusGeneral {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'legal');

    return;
}

#========================================================================================
# function     OnUnityViewCustomers
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewCustomers( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewCustomers.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewCustomers {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'customer') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnitySearchCustomers
#----------------------------------------------------------------------------------------
# syntax       OnUnitySearchCustomers( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnitySearchCustomers.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnitySearchCustomers {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'customer');

    return;
}

#========================================================================================
# function     OnUnitySearchOrders
#----------------------------------------------------------------------------------------
# syntax       OnUnitySearchOrders( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnitySearchOrders.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnitySearchOrders {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'order') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnitySearchOrdersInbox
#----------------------------------------------------------------------------------------
# syntax       OnUnitySearchOrdersInbox( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnitySearchOrdersInbox.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnitySearchOrdersInbox {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'order') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnityViewOrderSetup
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewOrderSetup( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewOrderSetup.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewOrderSetup {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'legal');

    return;
}

#========================================================================================
# function     OnUnityViewProductPortals
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewProductPortals( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewProductPortals.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewProductPortals {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'productportals') unless $Servlet->params('DELETE');

    return;
}


#========================================================================================
# function     OnUnityViewShippingList
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewShippingList( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewShippingList.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewShippingList {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'shipping') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnityViewCouponCampaigns
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewCouponCampaigns( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewCouponCampaigns.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewCouponCampaigns {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnViewGoogleAnalytics
#----------------------------------------------------------------------------------------
# syntax       OnViewGoogleAnalytics( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_ViewGoogleAnalytics.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnViewGoogleAnalytics {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing');

    return;
}

#========================================================================================
# function     OnUnityViewGoogleAdWords
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewGoogleAdWords( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewGoogleAdWords.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewGoogleAdWords {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing');

    return;
}

#========================================================================================
# function     OnUnityViewGoogleSearch
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewGoogleSearch( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewGoogleSearch.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewGoogleSearch {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing');

    return;
}

#========================================================================================
# function     OnUnityViewAmazonPortalList
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewAmazonPortalList( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewAmazonPortalList.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewAmazonPortalList {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnityViewEbayAuctions
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewEbayAuctions( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewEbayAuctions.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewEbayAuctions {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnityViewTrustedShopsCertificates
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewTrustedShopsCertificates( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewTrustedShopsCertificates.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewTrustedShopsCertificates {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnityViewGoogleShoppingPortalList
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewGoogleShoppingPortalList( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewGoogleShoppingPortalList.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewGoogleShoppingPortalList {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing') unless $Servlet->params('DELETE');

    return;
}

#========================================================================================
# function     OnUnityViewFacebookBusiness
#----------------------------------------------------------------------------------------
# syntax       OnUnityViewFacebookBusiness( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_Shop_UnityViewFacebookBusiness.
#               Writes the JSON data of the context sensitive apps.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Servlet - servlet object - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUnityViewFacebookBusiness {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    JSONWriteAppData($Servlet, 'marketing');

    return;
}

1;
