#==============================================================================
# �package      DE_EPAGES::FacebookBusiness::UI::Shop
# �base         DE_EPAGES::Order::UI::Shop
# �state        private
#==============================================================================
package DE_EPAGES::FacebookBusiness::UI::Shop;
use base DE_EPAGES::Presentation::UI::Object;

use strict;

use DE_EPAGES::Core::API::Error          qw( ExistsError GetError );
use DE_EPAGES::Core::API::PerlTools      qw( Compare GetCurrentDateTime AddDuration );
use DE_EPAGES::FacebookBusiness::API::Constants qw ( STATE_SEPERATOR );
use DE_EPAGES::FacebookBusiness::API::Object::RemoteFacebook;
use DE_EPAGES::Object::API::Factory qw( LoadRootObject );
use DE_EPAGES::Presentation::API::DereferrerToken qw( GenerateDereferrerToken );
use DE_EPAGES::Trigger::API::Trigger qw ( TriggerHook );
use MIME::Base64;

sub UnityViewFacebookBusiness {
    my $self = shift;
    my ($Servlet) = @_;

    my $FacebookBusinessEnvironment = LoadRootObject()->get('FacebookBusinessEnvironment');
    if (defined $FacebookBusinessEnvironment) {
        # build facebook oauth URL
        my $OAuthURL = $FacebookBusinessEnvironment->get('OAuthURL');
        my $RedirectURL = $Servlet->baseLineContentLocation . '?ViewAction=UnityMBO-ViewFacebookBusiness&ChangeAction=UnityMBO-SaveFacebookBusinessUserToken';

        # construct the state parameter as base64 string containing the
        # redirect URL and a corresponding token
        my $Token = GenerateDereferrerToken($RedirectURL);
        my $State = encode_base64($RedirectURL . STATE_SEPERATOR . $Token);

        $OAuthURL =~ s/{state-param}/$State/;
        $Servlet->vars('OAuthURL', $OAuthURL);

        my $FacebookBusinessShopEnvironment = DE_EPAGES::FacebookBusiness::API::Object::RemoteFacebook->new()->shopEnvironment($Servlet->object);
        my $UserAccessTokenExpiryDate = $FacebookBusinessShopEnvironment->get('UserAccessTokenExpiryDate') // undef;

        my $UserAccessTokenIsExpired = ((defined $UserAccessTokenExpiryDate) and 
                                       (Compare('DateTime',GetCurrentDateTime(),$UserAccessTokenExpiryDate) >= 0)) ? 1 : 0;

        $Servlet->vars('UserAccessTokenExpired', $UserAccessTokenIsExpired );

    }

    # trigger hook to allow the adding of context sensitive apps
    TriggerHook('UI_Shop_UnityViewFacebookBusiness', { 'Servlet' => $Servlet });

    return $self->SUPER::View($Servlet);
}

sub UnitySaveFacebookBusinessUserToken {
    my $self = shift;
    my ($Servlet) = @_;

    my $FBServerParams = $Servlet->params();

    # test if we have error elements in uri params
    $Servlet->form->executeFormError({
        'Name'        => 'FB_ERROR_BROWSERCODE',
        'FBName'      => $FBServerParams->{'error'},
        'Reason'      => $FBServerParams->{'error_reason'},
        'Description' => $FBServerParams->{'error_description'},
    }) if $FBServerParams->{'error'};

    # test if we have a browser auth code
    $Servlet->form->executeFormError({
        'Name'      => 'FB_NO_BROWSERCODE',
        'Reason'    => 'FB_NO_BROWSERCODE',
    }) unless $FBServerParams->{'code'};

    my $RemoteFacebook = DE_EPAGES::FacebookBusiness::API::Object::RemoteFacebook->new();

    # get access_code by browser code from facebook
    my $hResponse;
    eval {
        $hResponse = $RemoteFacebook->getOAuthUserTokenByAuthCode($FBServerParams->{'code'});
    };

    if(ExistsError()) {
        my $Error = GetError();
        my $FBErrorMessage = $Error->vars()->{'DecodedMessage'}->{'error'}->{'message'};
        $Servlet->form->executeFormError({
            'Name'        => 'FB_ERROR_AUTHCODE',
            'Reason'      => 'FB_ERROR_AUTHCODE',
            'Message'     => $FBErrorMessage,
        });
    }

    # save access_token for user in a fb shop environment 
    my $UserAccessToken = $hResponse->{'access_token'};
    return unless $UserAccessToken;

    # build datetime object
    my $ExpiryInSeconds = $hResponse->{'expires_in'};
    my $UserAccessTokenExpiresIn = AddDuration(GetCurrentDateTime()->clone, 'seconds', $ExpiryInSeconds - 10 );
    
    # get shop environment
    my $FacebookBusinessShopEnvironment = DE_EPAGES::FacebookBusiness::API::Object::RemoteFacebook->new()->shopEnvironment($Servlet->object);

    $FacebookBusinessShopEnvironment->set({
                                            'UserAccessToken'           => $UserAccessToken,
                                            'UserAccessTokenExpiryDate' => $UserAccessTokenExpiresIn,
                                          });

    # debug the token for getting user id
    eval {
        $hResponse = $RemoteFacebook->debugOAuthUserToken($UserAccessToken);;
    };
    if(ExistsError()) {
        my $Error = GetError();
        my $FBErrorMessage = $Error->vars()->{'DecodedMessage'}->{'error'}->{'message'};
        $Servlet->form->executeFormError({
            'Name'        => 'FB_ERROR_DEBUG_TOKEN',
            'Reason'      => 'FB_ERROR_DEBUG_TOKEN',
            'Message'     => $FBErrorMessage,
        });
    }

    # save userid
    #my $UserID = $hResponse->{'data'}->{'user_id'};
    
    
    
    #DE_EPAGES::Core::API::Log::LogDebug('$hResponse', $hResponse->{'data'}->{'user_id'}, 'DEBUG');

    




}
       
1;
