use strict;
use Test::More;
use DE_EPAGES::Core::API::Error  qw( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject);
use DE_EPAGES::FacebookBusiness::API::Object::RemoteFacebook;

sub Main {
    ConnectTestSite();
    ok( Init(), 'initialization' );

    my $System = LoadRootObject();
    my $Shop = $System->child( 'TestShop' );
    ok( $Shop->id, 'create shop' );

    my $RemoteFacebook = DE_EPAGES::FacebookBusiness::API::Object::RemoteFacebook->new();

    my $hCredentials = $RemoteFacebook->appCredentials();

    if ((exists $hCredentials->{'AppID'}) and ($hCredentials->{'AppID'} > 0 ) ){

        my $BrowserAuthCode = 'AQBd-PmwcvDx-Y0MSftOGhzbDRbrvKxFlkvrsPo7MmWmO7xiqQSAPUYKiamdGWHtfDMFtZTf9SfL2e8-xDb94gM-sWySfadSTcHeA-vcudWa4oltlXOy8UmKZROmJn-wPWFDsNl6An1dUHclHjCzAAkt8f3Ln6zTqaFuTht49BZFMvSVVFv79sJSm2cmSeEn4ED6ps2z2Cy-R2EE924kbufujogum9ozBLC6xhiYfjNQO4d1hABq6MxtLbmWwFbO1MWyQCndmfiGF3G9pmn_OwSO5256iIxWKqdwEFYu_GG23ryWRjVqbhdHmvWxGyTnDtN-MsAlIRnHWJDq63T2Ie4uLQpRZ-XzioKfkVjV6tbEGA';
        my $hResponse;
        eval {
            $hResponse = $RemoteFacebook->getOAuthUserTokenByAuthCode($BrowserAuthCode);
        };

        # test if we have an auth code expiration error
        ok(ExistsError && GetError->code eq 'API_CALL_ERROR' && GetError->message =~  m/This authorization code has expired./, 'auth code expired test');

        # get app access token and validate
        $hResponse = $RemoteFacebook->getAppAccessToken();

        ok( $hResponse->{'token_type'} eq 'bearer' , 'app access token type');
        ok( $hResponse->{'access_token'} =~ m/506631389986170|/ , 'app access token exists');

        $RemoteFacebook->setAppAccessToken('4711');
        $hResponse = $RemoteFacebook->getAppAccessToken();
        ok( $hResponse->{'access_token'} eq '4711' , 'app access token set so own value');

        $RemoteFacebook->setAppAccessToken(undef);
        $hResponse = $RemoteFacebook->getAppAccessToken();
        ok( $hResponse->{'access_token'} =~ m/506631389986170|/ , 'app access token correct after renewing');


        $hResponse = $RemoteFacebook->debugOAuthUserToken('jklh546j34hkhg');
        ok( $hResponse->{'data'}->{'error'}->{'message'} =~ m/Invalid OAuth access token/ , 'token debug Invalid OAuth access token');

    }

    ok( Cleanup(), 'Cleanup' );
    DisconnectSite();
    done_testing();
}

sub Cleanup {
    my $System = LoadRootObject();
    if( $System->existsChild( 'TestShop' ) ) {
        $System->child( 'TestShop' )->delete;
    }
    return 1;
}

sub Init {
    Cleanup();
    my $System = LoadRootObject();
    $System->insertChild( 'Shop', { Alias => 'TestShop' } );

    return 1;
}

RunScript(Sub=>\&Main, Debug=>1);
