CRED="\e[31m"; CGREEN="\e[32m"; CYELLOW="\e[33m"; CBLUE="\e[34m"; BOLD="\e[1m"; RESETALL="\e[0m";
CONFIG_FILE="ePagesApp.conf"
TEST_MODE=true

#---------------------------------------------------------------
#                  read configuration file
#---------------------------------------------------------------
set -o allexport; source "$CONFIG_FILE"; set +o allexport
echo -e -n "Read app config - APP_CLIENT_ID :${BOLD}${CGREEN}$APP_CLIENT_ID${RESETALL}."
if [ "$APP_CLIENT_ID" = "app_" ];
then echo -e -n "${BOLD}${CRED}
Error: Invalid config file.
Check confluence page for credentials and update the $CONFIG_FILE file.
https://epages.atlassian.net/wiki/spaces/RND/pages/1344045427/Mollie+API+v2
";echo ; exit; fi;
echo

ACCESS_TOKEN=$(cat  "generate-access-token-response.json" | jq -r '.access_token')
echo -e -n "Access token: ${BOLD}${CGREEN}$ACCESS_TOKEN${RESETALL}."
echo
if [ "$ACCESS_TOKEN" = "null" ];
then echo -e -n "${BOLD}${CRED}Error: Invalid token";echo ; exit; fi;

#---------------------------------------------------------------
#                  get profileId
#---------------------------------------------------------------
PROFILE_LIST=$(curl -X GET "https://api.mollie.com/v2/profiles" \
                    -H "Authorization: Bearer $ACCESS_TOKEN" | jq '.')
PROFILE_ID=$(echo "$PROFILE_LIST" | jq -r '._embedded.profiles[]  | select(.status == "verified").id')
echo
echo -e -n "profileId: ${BOLD}${CGREEN}$PROFILE_ID${RESETALL}."
echo

#---------------------------------------------------------------
#                  create order
#---------------------------------------------------------------
echo
echo -e -n "${BOLD}${CYELLOW}=== Create order on behalf of the merchant ===${RESETALL}"
echo
read -n 1 -p "Continue [Y]/n ? " resp
if [ "$resp" = "n" ]; then echo "Exit"; exit; fi
echo
# append profileId to order request
ORDER_REQUEST_JSON=$(cat "order-request.json" | jq '. + {"profileId":"'"$PROFILE_ID"'"} ')
# create order
ORDER_RESPONSE=$(curl -X POST https://api.mollie.com/v2/orders \
   -H "Content-Type: application/json" \
   -H "Authorization: Bearer $ACCESS_TOKEN" \
   -d "$ORDER_REQUEST_JSON" | jq '.' | tee "create-order-response.json")

echo "$ORDER_RESPONSE" | jq '.'
echo
echo -e -n "${BOLD}${CGREEN}Order created.${RESETALL}"
echo

#---------------------------------------------------------------
#                checkout url
# ---------------------------------------------------------------
echo
echo "Open checkout URL to pay the order:"
CHECKOUT_URL=$(echo "$ORDER_RESPONSE" | jq -r '._links.checkout.href')
echo $CHECKOUT_URL
echo
firefox $CHECKOUT_URL &


#---------------------------------------------------------------
#                get order
#---------------------------------------------------------------
echo
echo -e -n "${BOLD}${CYELLOW}=== Get order ===${RESETALL}"
echo
read -n 1 -p "Continue [Y]/n ? " resp
if [ "$resp" = "n" ]; then echo "Exit"; exit; fi
echo
ORDER_ID=$(cat "create-order-response.json" | jq -r ".id")


ORDER_RESPONSE=$(curl -X GET "https://api.mollie.com/v2/orders/$ORDER_ID?testmode=$TEST_MODE&embed=payments,refunds" \
    -H "Authorization: Bearer $ACCESS_TOKEN" | jq '.')

echo "$ORDER_RESPONSE" | jq '.'
echo "Order status:"
echo "$ORDER_RESPONSE" | jq '.status'
echo
echo "Done."
