#==============================================================================
# package      DE_EPAGES::MolliePayments::Hooks::OrderProcess
# state        private
#==============================================================================
package DE_EPAGES::MolliePayments::Hooks::OrderProcess;

use DE_EPAGES::ExternalPayment::API::Constants qw (DEFAULT_PAYMENT_STEP_POSITION);

use strict;



#========================================================================================
# function     OnRegisterCheckoutProcess
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnRegisterCheckoutProcess($hParams);
#----------------------------------------------------------------------------------------
# description  register payment step for checkout process
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnRegisterCheckoutProcess {
    my ($hParams) = @_;

    my $Servlet = $hParams->{'Servlet'};
    my $BasketOrderProcess = $hParams->{'BasketOrderProcess'};

    my $BasketOrder = $Servlet->object();
    my $LineItemContainer = $BasketOrder->container();
    return unless defined $LineItemContainer;

    my $LineItemPayment = $LineItemContainer->get('Payment');
    return unless defined($LineItemPayment);

    if ($LineItemPayment->instanceOf('LineItemPaymentMolliePayments')) {
        $BasketOrderProcess->addStep('MolliePayments', DEFAULT_PAYMENT_STEP_POSITION);
    }
    return;
}



#========================================================================================
# function     AfterRegisterCheckoutProcess
# state        public
#----------------------------------------------------------------------------------------
# syntax       AfterRegisterCheckoutProcess($hParams);
#----------------------------------------------------------------------------------------
# description  set order step; remove payment step if necessary
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub AfterRegisterCheckoutProcess {
    my ($hParams) = @_;

    my $Servlet = $hParams->{'Servlet'};
    my $BasketOrderProcess = $hParams->{'BasketOrderProcess'};

    my $BasketOrder = $Servlet->object();
    my $LineItemContainer = $BasketOrder->container();
    return unless defined $LineItemContainer;

    my $LineItemPayment = $LineItemContainer->get('Payment');
    return unless defined $LineItemPayment;

    if ($LineItemPayment->instanceOf('LineItemPaymentMolliePayments')) {
        if ($LineItemPayment->get('PaymentMethod')->get('DoPaymentOnBasket')) {
            $BasketOrderProcess->setOrderStep('MolliePayments');
        }
    }
    else {
        $BasketOrderProcess->deleteStep('MolliePayments');
    }

    return;
}

1;