#========================================================================================
# package      DE_EPAGES::MolliePayments::t::unit::MolliePaymentsUrlBuilder
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::MolliePayments::API::MolliePaymentsUrlBuilder
#========================================================================================
package DE_EPAGES::MolliePayments::t::unit::UI_MolliePayments;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::Exception;
use Test::MockObject::Extends;
use Test::More;

use strict;

use constant MBO_URL => 'https://unity-molliep.vm-hsilva.intern.epages.de/epages/unity_molliep.admin/sec7585fa3953/?ViewAction=MBO-ViewSettings&ObjectID=22404';

sub test {
    my $self = shift;

    $self->test_BuildConnectAndReconnectUrl();
    $self->test_BuildRedirectToMboUrl();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_BuildConnectAndReconnectUrl {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $SUT = $self->_createSUT();

    my $actualResult = $SUT->buildConnectAndReconnectUrl(MBO_URL);
    my $expectedResult = 'https://www.mollie.com/oauth2/authorize?response_type=code&approval_prompt=force&redirect_uri=https%3A%2F%2Fredirect_uri.de&client_id=12345&scope=dsadasd+retertert&state=https%3A%2F%2Funity-molliep.vm-hsilva.intern.epages.de%2Fepages%2Funity_molliep.admin%2Fsec7585fa3953%2F%3FViewAction%3DMBO-ViewSettings%26ObjectID%3D22404';
    is(  $actualResult, $expectedResult, "$SubTestName - Merchant connect and reconnect Url was correctly assembled");

    return;
}

sub test_BuildRedirectToMboUrl {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $SUT = $self->_createSUT();

    my $hQueryParameters = {
        'code' => 'authorization_code',
        'state' => [MBO_URL]
    };
    my $actualResult = $SUT->buildRedirectToMboUrl($hQueryParameters);
    my $expectedResult = MBO_URL.'&code=authorization_code';
    is(  $actualResult, $expectedResult, "$SubTestName - MBO link was correctly assembled.");

    return;
}
#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------

sub _createSUT {
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::MolliePayments::API::MolliePaymentsUrlBuilder');

    $Mockify->addMockWithReturnValueAndParameterCheck( '_buildQueryParameters', {
        'response_type'   => 'code',
        'client_id'       => 12345,
        'scope'           => "dsadasd retertert",
        'redirect_uri'    => "https://redirect_uri.de",
        'state'           => MBO_URL,
        'approval_prompt' => 'force',
    }, [ {'string' => MBO_URL} ]);


    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
