#========================================================================================
# package      DE_EPAGES::MolliePayments::t::unit::UI_JSON
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for UI::Provider
#========================================================================================
package DE_EPAGES::MolliePayments::t::unit::UI_JSON;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Mockify;
use Test::Mockify::Verify qw ( WasCalled GetParametersFromMockifyCall );
use Test::Mockify::Matcher qw ( HashRef Any Object String Number);

use Test::Exception;
use Test::MockObject::Extends;
use Test::More;

use strict;

use constant PROFILE_ID => 'pfl_v9hTwCvYq1';

sub test {
    my $self = shift;

    $self->test_GetMolliePaymentsMethods();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_GetMolliePaymentsMethods {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $hParams =  {
        'IsInTestMode' => 1,
        'ProfileId' => PROFILE_ID
    };

    my $Servlet = $self->_createServlet($hParams);

    my $MethodsRequest = $self->_createMethodsHandler();
    my $MollieService = $self->_createService();

    my $SUT = $self->_createSUT($MethodsRequest, $MollieService);

    $SUT->GetMolliePaymentsMethods($Servlet);

    is_deeply(  GetParametersFromMockifyCall( $MethodsRequest, 'withProfileId' ),
                [ PROFILE_ID ],
                "$SubTestName - Methods withProfileId was called with correct ProfileId"
    );

    is_deeply(  GetParametersFromMockifyCall( $MollieService, 'withTestMode' ),
                [ 1 ],
                "$SubTestName - MollieService withTestMode was called with correct IsInTestMode"
    );

    ok(WasCalled($MollieService, 'doGetRequest'), "$SubTestName - MollieService doGetRequest was called");

    is_deeply(  GetParametersFromMockifyCall( $SUT, '_writeContentOutput' ),
                [ {"result" => "result"} ],
                "$SubTestName - MollieService _writeContentOutput was called with correct parameter"
    );

    return;
}


#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------
sub _createForm {
    my $self = shift;

    my $Mockify = Test::Mockify->new( 'DE_EPAGES::Presentation::API::Form');
    return $Mockify->getMockObject();
}

sub _createServlet {
    my $self = shift;
    my ($hParams) = @_;

    my $PaymentMethod = $self->_createPaymentMethod();
    my $MockifyServlet = DE_EPAGES::Test::Mock::MockifyServlet->new($PaymentMethod);
    $MockifyServlet->addMockWithReturnValue( 'form', $self->_createForm() );

    $MockifyServlet->addParam( 'IsInTestMode', $hParams->{'IsInTestMode'} );
    $MockifyServlet->addParam( 'ProfileId', $hParams->{'ProfileId'} );

    return $MockifyServlet->getMockObject();
}

sub _createSUT {
    my $self = shift;
    my ($MethodsRequest, $MollieService) = @_;

    my $Mockify = Test::Mockify->new('DE_EPAGES::MolliePayments::UI::JSON');

    $Mockify->mock('_createMethodsHandler')->when(HashRef())->thenReturn($MethodsRequest);
    $Mockify->mock('_createMolliePaymentsService')->when(Object('DE_EPAGES::MolliePayments::API::Requests::Methods'))->thenReturn($MollieService);
    $Mockify->mock('_writeContentOutput')->when(HashRef())->thenReturnUndef();
    $Mockify->mock('_LogPayment')->when(String(), HashRef(), Any(), Any())->thenReturnUndef();

    return $Mockify->getMockObject();
}

sub _createMethodsHandler {
    my $self = shift;

    my $Mockify = Test::Mockify->new('DE_EPAGES::MolliePayments::API::Requests::Methods');
    $Mockify->mock( 'withProfileId')->when(String())->thenCall(sub{return shift;});

    return $Mockify->getMockObject();
}

sub _createService {
    my $self = shift;

    my $Mockify = Test::Mockify->new('DE_EPAGES::MolliePayments::API::MolliePaymentsService');
    $Mockify->mock('doGetRequest')->when()->thenReturn({"result" => "result"});
    $Mockify->mock('withTestMode')->when(Number())->thenReturn($Mockify->getMockObject());

    return $Mockify->getMockObject();
}

sub _createPaymentMethod {
    my $self = shift;

    my $hAttributes = {
        'ID' => 123 
    };
    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::MolliePayments::API::Object::PaymentMethodMolliePayments', $hAttributes
    );

    return $MockifyPaymentMethod->getMockObject();
}

__PACKAGE__->runScript();
