#========================================================================================
# package      DE_EPAGES::MolliePayments::t::unit::UI_MolliePayments
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for UI::Provider
#========================================================================================
package DE_EPAGES::MolliePayments::t::unit::UI_MolliePayments;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::Mockify qw ( GetParametersFromMockifyCall );
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Exception;
use Test::MockObject::Extends;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_BacklinkMolliePaymentsOnboardingRedirect();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_BacklinkMolliePaymentsOnboardingRedirect {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $SUT = $self->_createSUT();

    my $Servlet = $self->_createServlet();

    $SUT->BacklinkMolliePaymentsOnboarding($Servlet);

    is_deeply(  GetParametersFromMockifyCall( $SUT, '_RedirectToURL' ),
                [ 'www.ePages.com/QueryString' ],
                "$SubTestName - _RedirectToURL was called with QueryValues(hashref) in Form."
    );

    return;
}


#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------
sub _createForm {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new( 'DE_EPAGES::Presentation::API::Form');
    $Mockify->addMockWithReturnValue('queryValues', {'key' => 'value'});
    return $Mockify->getMockObject();
}

sub _createServlet {
    my $self = shift;
    my ($hVars) = @_;

    my $MockifyProvider = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::ShopConfiguration::API::Object::Provider', {} );
    my $Provider = $MockifyProvider->getMockObject();
    my $Mockify = DE_EPAGES::Test::Mock::MockifyServlet->new($Provider);

    $Mockify->addMockWithReturnValue('form', $self->_createForm());

    return $Mockify->getMockObject();
}

sub _createSUT {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::MolliePayments::UI::MolliePayments');

    my $MolliePaymentsUrlBuilder = $self->_createMolliePaymentsUrlBuilder();
    $Mockify->addMockWithReturnValue( '_createMolliePaymentsUrlBuilder', $MolliePaymentsUrlBuilder );

    $Mockify->addMockWithReturnValueAndParameterCheck( '_RedirectToURL', undef, [ {'string' => 'www.ePages.com/QueryString'} ] );

    return $Mockify->getMockObject();
}

sub _createMolliePaymentsUrlBuilder {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new( 'DE_EPAGES::MolliePayments::API::MolliePaymentsUrlBuilder');
    $Mockify->addMockWithReturnValueAndParameterCheck('buildRedirectToMboUrl', 'www.ePages.com/QueryString', [ {'hashref' => {'key' => 'value'}} ]);

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
