#========================================================================================
# package      DE_EPAGES::ShopMailType::API::Resource::ShopMail
# state        public
# base         DE_EPAGES::Shop::API::Resource::BaseShopResource
# description  implements the REST resource for sending a plain text mail
#========================================================================================
package DE_EPAGES::ShopMailType::API::Resource::ShopMail;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Core::API::TestParameter qw ( TestString TestEMailAddress );
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Mail::API::Mail;
use DE_EPAGES::MailType::API::Object::SmtpConnection;
use DE_EPAGES::Core::API::Log qw ( LogError LogDebug GetLog );

use feature 'switch';

use strict;

sub service {
    return LoadObjectByPath('/RestServices/ShopMail');
}

sub class {
    return 'Shop';
}

sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        PUT => [
            ['put', 'application/json'],
            ['put', 'application/vnd.epages.v1+json'],
        ],
    }->{$RequestMethod};
}

sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/shopmail/?$|;

    return 1;
}

sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    return [ $Object ];
}

sub put {
    my $self = shift;
    my ($Shop, $hRequestBody) = @_;

    GetLog->debug( 'put /RestServices/ShopMail' );
    LogDebug('hRequestBody',$hRequestBody);

    my $Result = { 'mailStatus' => 'ok' };
    eval {
        TestString('senderName', $hRequestBody->{senderName});
        TestEMailAddress('senderAddress', $hRequestBody->{senderAddress});
        TestEMailAddress('recipientAddress', $hRequestBody->{recipientAddress});
        TestString('subject', $hRequestBody->{subject});
        TestString('message', $hRequestBody->{message});
        my $Mail = DE_EPAGES::Mail::API::Mail->new( {
                'SUBJECT' => $hRequestBody->{subject},
                'FROM'    => $hRequestBody->{recipientAddress},
                'TO'      => [ $hRequestBody->{recipientAddress} ],
                'REPLY'   => sprintf('%s <%s>', $hRequestBody->{senderName}, $hRequestBody->{senderAddress} ),
            }
        );
        $Mail->addText( {
                'content'      => $hRequestBody->{message},
                'encoding'     => 'quoted-printable',
                'type'         => 'text/plain',
                'type.charset' => 'utf-8',
            }
        );
        my $Connection = DE_EPAGES::MailType::API::Object::SmtpConnection->new;
        $Connection->open;
        $Connection->send( $Mail->createMail(), $Mail->getHeader() );
        $Connection->close;
    };
    if (ExistsError()) {
        my $Error = GetError();
        LogError($Error);
        $Result = { 'mailStatus' => 'not ok', 'errorMessage' => $Error->message, };
    }
    return $Result;
}

1;