use strict;
use Getopt::Long;
use Time::HiRes qw (time);
use Test::More;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Test::API::TranslationFiles qw(
    TestCartridges
    TestCompany
    TestTranslationFile
);

sub Main {

    local $| = 1;

    my $Files;
    my $Cartridges;
    my $Companies;
    my $Help;

    GetOptions(
        'help'         => \$Help,
        'cartridges=s' => \$Cartridges,
        'files=s'      => \$Files,
        'companyies=s' => \$Companies,
    );

    usage() if $Help;

    if ( defined $Cartridges && defined $Files) {
        print STDERR "Please provide only -cartridges or -files.\n\n";
        usage();
    }
    my $time1 = time;

    my @Companies = defined $Companies ? split(/,/, $Companies) : ('DE_EPAGES');

    foreach my $Company (@Companies) {
        if (defined $Cartridges) {
            my @Cartridges = split(/,/, $Cartridges);
            TestCartridges(\@Cartridges, $Company);
        } elsif (defined $Files) {
            my @Files = split(/,/, $Files);

            foreach my $File (@Files) {
                TestTranslationFile($File);
            }
        } else {
            TestCompany($Company);
        }
    }

    done_testing();

    my $time2 = time;
    printf "need %.1f seconds\n", $time2 - $time1;
}

sub usage {
    print <<END_USAGE;
Description:
    Perform the test ../t/translationFiles.t
    on a single or multiple translation files
    resp. a single or multiple cartridges
    resp. a single or multiple companies

Usage:
    perl $0 [options]

options:
    -cartridges cartridge names (as comma separated list)    (optional)
    -files      file paths (as comma separated list)         (optional)
    -companies  cartridge folders (as comma separated list)  (optional, default: DE_EPAGES)
flags:
    -help       show the command line options

Examples:
    perl $0 -cartridges Product
    perl $0 -cartridges Product,Shop,Customer
    perl $0 -files \$EPAGES_CARTRIDGES/DE_EPAGES/Product/Templates/Dictionary.de.xml
    perl $0 -files \$EPAGES_CARTRIDGES/DE_EPAGES/Product/Templates/Dictionary.de.xml,
        \$EPAGES_CARTRIDGES/DE_EPAGES/Product/Templates/Dictionary.en.xml
    perl $0 -company DE_EPAGES_CONSULTING
    perl $0 -company DE_EPAGES_CONSULTING,DE_EPAGES_SAGE
    perl $0 -company DE_EPAGES_CONSULTING -cartridge SingleSignOn
END_USAGE
    exit 2;
}

RunScript( 'Sub' => \&Main );